
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef hueblob_MSG_LIB_H
#define hueblob_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "hueblobType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  HUEBLOB_MBOX_NAME                  genomInstanceName("hueblob")

#define  HUEBLOB_MAX_RQST_SIZE              788

#define  HUEBLOB_MBOX_RQST_SIZE       \
 (BUF_SIZE(HUEBLOB_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  HUEBLOB_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  HUEBLOB_MAX_REPLY_SIZE             420

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  HUEBLOB_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(HUEBLOB_MAX_REPLY_SIZE) \
   + BUF_SIZE(HUEBLOB_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define HUEBLOB_DISPLAY_RQST 0
#define HUEBLOB_STOPLOOP_RQST 1
#define HUEBLOB_SETPARAMS_RQST 2
#define HUEBLOB_SETOBJECT_RQST 3
#define HUEBLOB_SETIMAGE_RQST 4
#define HUEBLOB_GETBOX_RQST 5
#define HUEBLOB_GETBOXLOOP_RQST 6
#define HUEBLOB_TRACKBLOB_RQST 7
#define HUEBLOB_TRACKCHESSBOARD_RQST 8
#define HUEBLOB_ABORT_RQST 9


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS hueblobClientInit (CLIENT_ID *pClientId);

STATUS hueblobClientEnd (CLIENT_ID clientId);

int hueblobAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int hueblobAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int hueblobAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS hueblobDisplayRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 HueBlobBool *(in_display),
					 int replyTimeOut);

int hueblobDisplayReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int hueblobDisplayRqstAndRcv (CLIENT_ID clientId, 
				 HueBlobBool *(in_display), 
				 
				 int *bilan);




extern STATUS hueblobStopLoopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int hueblobStopLoopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int hueblobStopLoopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS hueblobSetParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_threshold),
					 int replyTimeOut);

int hueblobSetParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int hueblobSetParamsRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_threshold), 
				 
				 int *bilan);




extern STATUS hueblobSetObjectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobObject *(in_object),
					 int replyTimeOut);

extern int hueblobSetObjectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int hueblobSetObjectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobObject *(in_object), 
					
					int *activity, int *bilan);

extern int hueblobSetObjectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobObject *(in_object), 
					
					int *activity,
					int *bilan);




extern STATUS hueblobSetImageRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobInput *(in_image),
					 int replyTimeOut);

extern int hueblobSetImageReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int hueblobSetImageRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobInput *(in_image), 
					
					int *activity, int *bilan);

extern int hueblobSetImageRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobInput *(in_image), 
					
					int *activity,
					int *bilan);




extern STATUS hueblobGetBoxRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobImageBox *(in_video),
					 int replyTimeOut);

extern int hueblobGetBoxReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      HueBlobBox *(out_box),
				      int *activity, int *bilan);


extern int hueblobGetBoxRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobImageBox *(in_video), 
					HueBlobBox *(out_box),
					int *activity, int *bilan);

extern int hueblobGetBoxRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobImageBox *(in_video), 
					HueBlobBox *(out_box),
					int *activity,
					int *bilan);




extern STATUS hueblobGetBoxLoopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobImageBox *(in_video),
					 int replyTimeOut);

extern int hueblobGetBoxLoopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      HueBlobBox *(out_box),
				      int *activity, int *bilan);


extern int hueblobGetBoxLoopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobImageBox *(in_video), 
					HueBlobBox *(out_box),
					int *activity, int *bilan);

extern int hueblobGetBoxLoopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobImageBox *(in_video), 
					HueBlobBox *(out_box),
					int *activity,
					int *bilan);




extern STATUS hueblobTrackBlobRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobTrackBlob *(in_blob),
					 int replyTimeOut);

extern int hueblobTrackBlobReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int hueblobTrackBlobRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobTrackBlob *(in_blob), 
					
					int *activity, int *bilan);

extern int hueblobTrackBlobRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobTrackBlob *(in_blob), 
					
					int *activity,
					int *bilan);




extern STATUS hueblobTrackChessBoardRqstSend (CLIENT_ID clientId, int *pRqstId,
					 HueBlobTrackChessboard *(in_chessboard),
					 int replyTimeOut);

extern int hueblobTrackChessBoardReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int hueblobTrackChessBoardRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					HueBlobTrackChessboard *(in_chessboard), 
					
					int *activity, int *bilan);

extern int hueblobTrackChessBoardRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					HueBlobTrackChessboard *(in_chessboard), 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* hueblob_MSG_LIB_H */

